<?php
/**
 * Helper functions related to customizer and options.
 *
 * @package Restaurantz
 */

if ( ! function_exists( 'restaurantz_get_global_layout_options' ) ) :

	/**
	 * Returns global layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function restaurantz_get_global_layout_options() {

		$choices = array(
			'left-sidebar'            => esc_html__( 'Primary Sidebar - Content', 'restaurantz-pro' ),
			'right-sidebar'           => esc_html__( 'Content - Primary Sidebar', 'restaurantz-pro' ),
			'three-columns'           => esc_html__( 'Three Columns ( Secondary - Content - Primary )', 'restaurantz-pro' ),
			'three-columns-pcs'       => esc_html__( 'Three Columns ( Primary - Content - Secondary )', 'restaurantz-pro' ),
			'three-columns-cps'       => esc_html__( 'Three Columns ( Content - Primary - Secondary )', 'restaurantz-pro' ),
			'three-columns-psc'       => esc_html__( 'Three Columns ( Primary - Secondary - Content )', 'restaurantz-pro' ),
			'three-columns-pcs-equal' => esc_html__( 'Three Columns ( Equal Primary - Content - Secondary )', 'restaurantz-pro' ),
			'three-columns-scp-equal' => esc_html__( 'Three Columns ( Equal Secondary - Content - Primary )', 'restaurantz-pro' ),
			'no-sidebar'              => esc_html__( 'No Sidebar', 'restaurantz-pro' ),
		);
		$output = apply_filters( 'restaurantz_filter_layout_options', $choices );
		return $output;

	}

endif;

if ( ! function_exists( 'restaurantz_get_pagination_type_options' ) ) :

	/**
	 * Returns pagination type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function restaurantz_get_pagination_type_options() {

		$choices = array(
			'default'               => esc_html__( 'Default (Older / Newer Post)', 'restaurantz-pro' ),
			'numeric'               => esc_html__( 'Numeric', 'restaurantz-pro' ),
			'infinite-scroll'       => esc_html__( 'Infinite Scroll - Scroll', 'restaurantz-pro' ),
			'infinite-scroll-click' => esc_html__( 'Infinite Scroll - Click', 'restaurantz-pro' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'restaurantz_get_breadcrumb_type_options' ) ) :

	/**
	 * Returns breadcrumb type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function restaurantz_get_breadcrumb_type_options() {

		$choices = array(
			'disabled' => esc_html__( 'Disabled', 'restaurantz-pro' ),
			'simple'   => esc_html__( 'Simple', 'restaurantz-pro' ),
			'advanced' => esc_html__( 'Advanced', 'restaurantz-pro' ),
		);
		return $choices;

	}

endif;


if ( ! function_exists( 'restaurantz_get_archive_layout_options' ) ) :

	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function restaurantz_get_archive_layout_options() {

		$choices = array(
			'full'    => esc_html__( 'Full Post', 'restaurantz-pro' ),
			'excerpt' => esc_html__( 'Post Excerpt', 'restaurantz-pro' ),
		);
		$output = apply_filters( 'restaurantz_filter_archive_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'restaurantz_get_image_sizes_options' ) ) :

	/**
	 * Returns image sizes options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool  $add_disable True for adding No Image option.
	 * @param array $allowed Allowed image size options.
	 * @return array Image size options.
	 */
	function restaurantz_get_image_sizes_options( $add_disable = true, $allowed = array(), $show_dimension = true ) {

		global $_wp_additional_image_sizes;
		$get_intermediate_image_sizes = get_intermediate_image_sizes();
		$choices = array();
		if ( true === $add_disable ) {
			$choices['disable'] = esc_html__( 'No Image', 'restaurantz-pro' );
		}
		$choices['thumbnail'] = esc_html__( 'Thumbnail', 'restaurantz-pro' );
		$choices['medium']    = esc_html__( 'Medium', 'restaurantz-pro' );
		$choices['large']     = esc_html__( 'Large', 'restaurantz-pro' );
		$choices['full']      = esc_html__( 'Full (original)', 'restaurantz-pro' );

		if ( true === $show_dimension ) {
			foreach ( array( 'thumbnail', 'medium', 'large' ) as $key => $_size ) {
				$choices[ $_size ] = $choices[ $_size ] . ' (' . get_option( $_size . '_size_w' ) . 'x' . get_option( $_size . '_size_h' ) . ')';
			}
		}

		if ( ! empty( $_wp_additional_image_sizes ) && is_array( $_wp_additional_image_sizes ) ) {
			foreach ( $_wp_additional_image_sizes as $key => $size ) {
				$choices[ $key ] = $key;
				if ( true === $show_dimension ){
					$choices[ $key ] .= ' ('. $size['width'] . 'x' . $size['height'] . ')';
				}
			}
		}

		if ( ! empty( $allowed ) ) {
			foreach ( $choices as $key => $value ) {
				if ( ! in_array( $key, $allowed ) ) {
					unset( $choices[ $key ] );
				}
			}
		}

		return $choices;

	}

endif;


if ( ! function_exists( 'restaurantz_get_image_alignment_options' ) ) :

	/**
	 * Returns image options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function restaurantz_get_image_alignment_options() {

		$choices = array(
			'none'   => _x( 'None', 'Alignment', 'restaurantz-pro' ),
			'left'   => _x( 'Left', 'Alignment', 'restaurantz-pro' ),
			'center' => _x( 'Center', 'Alignment', 'restaurantz-pro' ),
			'right'  => _x( 'Right', 'Alignment', 'restaurantz-pro' ),
		);
		return $choices;

	}

endif;

if( ! function_exists( 'restaurantz_get_customizer_font_options' ) ) :

	/**
	 * Returns customizer font options.
	 *
	 * @since 1.0.0
	 */
	function restaurantz_get_customizer_font_options(){

		$web_fonts = restaurantz_get_web_fonts();
		$os_fonts  = restaurantz_get_os_fonts();

		$web_fonts = array_merge( $web_fonts, $os_fonts );

		if ( ! empty( $web_fonts ) ) {
			ksort( $web_fonts );
		}

		$choices = array();

		if ( ! empty( $web_fonts ) ) {
			foreach ( $web_fonts as $k => $v ) {
				$choices[$k] = esc_html( $v['label'] );
			}
		}
		return $choices;

	}

endif;

if( ! function_exists( 'restaurantz_get_web_fonts' ) ) :

	/**
	 * Returns web font options.
	 *
	 * @since 1.0.0
	 */
	function restaurantz_get_web_fonts(){

		$choices = array(
			'tangerine' => array(
				'name'  => 'Tangerine',
				'label' => "'Tangerine', cursive",
				),
			'open-sans' => array(
				'name'  => 'Open Sans',
				'label' => "'Open Sans', sans-serif",
				),
			'merriweather-sans' => array(
				'name'  => 'Merriweather Sans',
				'label' => "'Merriweather Sans', sans-serif",
				),
			'roboto' => array(
				'name'  => 'Roboto',
				'label' => "'Roboto', sans-serif",
				),
			'arizonia' => array(
				'name'  => 'Arizonia',
				'label' => "'Arizonia', cursive",
				),
			'raleway' => array(
				'name'  => 'Raleway',
				'label' => "'Raleway', sans-serif",
				),
			'droid-sans' => array(
				'name'  => 'Droid Sans',
				'label' => "'Droid Sans', sans-serif",
				),
			'lato' => array(
				'name'  => 'Lato',
				'label' => "'Lato', sans-serif",
				),
			'dosis' => array(
				'name'  => 'Dosis',
				'label' => "'Dosis', sans-serif",
				),
			'slabo-27px' => array(
				'name'  => 'Slabo 27px',
				'label' => "'Slabo 27px', serif",
				),
			'oswald' => array(
				'name'  => 'Oswald',
				'label' => "'Oswald', sans-serif",
				),
			'pt-sans-narrow' => array(
				'name'  => 'PT Sans Narrow',
				'label' => "'PT Sans Narrow', sans-serif",
				),
			'josefin-slab' => array(
				'name'  => 'Josefin Slab',
				'label' => "'Josefin Slab', serif",
				),
			'alegreya' => array(
				'name'  => 'Alegreya',
				'label' => "'Alegreya', serif",
				),
			'exo' => array(
				'name'  => 'Exo',
				'label' => "'Exo', sans-serif",
				),
			'signika' => array(
				'name'  => 'Signika',
				'label' => "'Signika', sans-serif",
				),
			'lobster' => array(
				'name'  => 'Lobster',
				'label' => "'Lobster', cursive",
				),
			'indie-flower' => array(
				'name'  => 'Indie Flower',
				'label' => "'Indie Flower', cursive",
				),
			'shadows-into-light' => array(
				'name'  => 'Shadows Into Light',
				'label' => "'Shadows Into Light', cursive",
				),
			'kaushan-script' => array(
				'name'  => 'Kaushan Script',
				'label' => "'Kaushan Script', cursive",
				),
			'dancing-script' => array(
				'name'  => 'Dancing Script',
				'label' => "'Dancing Script', cursive",
				),
			'fredericka-the-great' => array(
				'name'  => 'Fredericka the Great',
				'label' => "'Fredericka the Great', cursive",
				),
			'covered-by-your-grace' => array(
				'name'  => 'Covered By Your Grace',
				'label' => "'Covered By Your Grace', cursive",
				),
			);
		$choices = apply_filters( 'restaurantz_filter_web_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}

		return $choices;

	}

endif;

if( ! function_exists( 'restaurantz_get_os_fonts' ) ) :

	/**
	 * Returns OS font options.
	 *
	 * @since 1.0.0
	 */
	function restaurantz_get_os_fonts(){

		$choices = array(
			'arial' => array(
				'name'  => 'Arial',
				'label' => "'Arial', sans-serif",
				),
			'georgia' => array(
				'name'  => 'Georgia',
				'label' => "'Georgia', serif",
				),
			'cambria' => array(
				'name'  => 'Cambria',
				'label' => "'Cambria', Georgia, serif",
				),
			'tahoma' => array(
				'name'  => 'Tahoma',
				'label' => "'Tahoma', Geneva, sans-serif",
				),
			'sans-serif' => array(
				'name'  => 'Sans Serif',
				'label' => "'Sans Serif', Arial",
				),
			'verdana' => array(
				'name'  => 'Verdana',
				'label' => "'Verdana', Geneva, sans-serif",
				),
			);
		$choices = apply_filters( 'restaurantz_filter_os_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}
		return $choices;

	}

endif;

if( ! function_exists( 'restaurantz_get_font_family_from_key' ) ) :

	/**
	 * Return font family from font slug.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Font slug.
	 * @return string Font name.
	 */
	function restaurantz_get_font_family_from_key( $key ){

		$output = '';

		$web_fonts = restaurantz_get_web_fonts();
		$os_fonts  = restaurantz_get_os_fonts();

		$fonts = array_merge( $web_fonts, $os_fonts );

		if ( isset( $fonts[ $key ] ) ) {
			$output = $fonts[ $key ]['label'];
		}
		return $output;

	}

endif;

if( ! function_exists( 'restaurantz_get_font_family_theme_settings_options' ) ) :

	/**
	 * Returns font family theme settings options.
	 *
	 * @since 1.0.0
	 */
	function restaurantz_get_font_family_theme_settings_options(){

		$choices = array(
			'font_site_title' => array(
				'label'   => __( 'Site Title', 'restaurantz-pro' ),
				'default' => 'oswald',
				),
			'font_site_tagline' => array(
				'label'   => __( 'Site Tagline', 'restaurantz-pro' ),
				'default' => 'open-sans',
				),
			'font_site_default' => array(
				'label'   => __( 'Default', 'restaurantz-pro' ),
				'default' => 'open-sans',
				),
			'font_page_title' => array(
				'label'   => __( 'Page Title', 'restaurantz-pro' ),
				'default' => 'tangerine',
				),
			'font_content_title' => array(
				'label'   => __( 'Content Title', 'restaurantz-pro' ),
				'default' => 'open-sans',
				),
			'font_content_body' => array(
				'label'   => __( 'Content Body', 'restaurantz-pro' ),
				'default' => 'open-sans',
				),
			'font_main_widget_title' => array(
				'label'   => __( 'Main Widget Title', 'restaurantz-pro' ),
				'default' => 'tangerine',
				),
			'font_heading_tags' => array(
				'label'   => __( 'Heading Tags', 'restaurantz-pro' ),
				'default' => 'oswald',
				),
			'font_navigation' => array(
				'label'   => __( 'Navigation', 'restaurantz-pro' ),
				'default' => 'open-sans',
				),
			);
		return $choices;

	}

endif;

if( ! function_exists( 'restaurantz_get_default_colors' ) ) :

  /**
   * Returns default colors.
   *
   * @since 1.0.0
   *
   * @param string $scheme Color scheme.
   * @return array Color values based on scheme.
   */
	function restaurantz_get_default_colors( $scheme = 'default' ){

		$output = array();

		switch ( $scheme ) {

			case 'default':
			default:
			$output = array(

				// Basic.
				'color_basic_text'                    => '#313131',
				'color_basic_link'                    => '#7f390a',
				'color_basic_link_hover'              => '#551919',
				'color_basic_heading'                 => '#7f390a',
				'color_basic_button_background'       => '#7f390a',
				'color_basic_button_text'             => '#ffffff',
				'color_basic_button_background_hover' => '#551919',
				'color_basic_button_text_hover'       => '#ffffff',
				'color_basic_widget_title'            =>'#7f390a',
				// Header.
				'color_header_background'  => '#000000',
				'color_header_title'       => '#ffffff',
				'color_header_title_hover' => '#f9a400',
				'color_header_tagline'     => '#313131',

				// Content.
				'color_content_background'      => '#dddddd',
				'color_content_text'            => '#313131',
				'color_content_link'            => '#7f390a',
				'color_content_link_hover'      => '#551919',
				'color_content_meta_link'       => '#313131',
				'color_content_meta_link_hover' => '#551919',
				'color_content_meta_icon'       => '#313131',

				// Sidebar.
				'color_sidebar_title'      		  => '#7f390a',
				'color_sidebar_title_broder'      => '#f9a400',
				'color_sidebar_text'       		  => '#313131',
				'color_sidebar_link'       		  => '#7f390a',
				'color_sidebar_link_hover' 		  => '#551919',

				// Primary Menu.
				'color_primary_menu_link'                  => '#ffffff',
				'color_primary_menu_link_hover'            => '#ffffff',
				'color_primary_menu_link_underline_hover'  => '#f9a400',
				'color_primary_sub_menu_background' 	   => '#000000',

				//Custom Banners
				'color_custom_banner_main_background' => '#000',
				'color_custom_banner_page_title'      => '#ffffff',
				'color_custom_banner_divider'         => '#f9a400',
				'color_custom_banner_divider_border'  => '#313131',

				// Footer Widgets.
				'color_footer_widgets_background' => '#000000',
				'color_footer_widgets_title'      => '#313131',
				'color_footer_widgets_text'       => '#313131',
				'color_footer_widgets_link'       => '#f9a400',
				'color_footer_widgets_link_hover' => '#551919',
				'color_footer_widgets_title_border'  => '#f9a400',

				// Footer area.
				'color_footer_area_background' => '#2b2a2a',
				'color_footer_area_text'       => '#ffffff',
				'color_footer_area_link'       => '#7f390a',
				'color_footer_area_link_hover' => '#ffffff',

				// Go To Top.
				'color_goto_top_icon'             => '#ffffff',
				'color_goto_top_icon_hover'       => '#ffffff',
				'color_goto_top_background'       => '#7f390a',
				'color_goto_top_background_hover' => '#7f390a',

				// Pagination.
				'color_pagination_link'                  => '#ffffff',
				'color_pagination_link_hover'            => '#ffffff',
				'color_pagination_link_background'       => '#7f390a',
				'color_pagination_link_background_hover' => '#551919',

				// Breadcrumb.
				'color_breadcrumb_background' => '#ffffff',
				'color_breadcrumb_link'       => '#7f390a',
				'color_breadcrumb_link_hover' => '#551919',
				'color_breadcrumb_text'       => '#313131',

			);
			break;

		} // End switch.

	return $output;

	}

endif;


if( ! function_exists( 'restaurantz_get_color_theme_settings_options' ) ) :

  /**
   * Returns color theme settings options.
   *
   * @since 1.0.0
   */
  function restaurantz_get_color_theme_settings_options(){

  	$choices = array(

		// Basic.
  		'color_basic_text' => array(
  			'label'   => __( 'Text Color', 'restaurantz-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_link' => array(
  			'label'   => __( 'Link Color', 'restaurantz-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_heading' => array(
  			'label'   => __( 'Heading Color', 'restaurantz-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_text' => array(
  			'label'   => __( 'Button Text Color', 'restaurantz-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_background' => array(
  			'label'   => __( 'Button Background Color', 'restaurantz-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_text_hover' => array(
  			'label'   => __( 'Button Text Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_background_hover' => array(
  			'label'   => __( 'Button Background Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_widget_title' => array(
  			'label'   => __( 'Widget Title Color', 'restaurantz-pro' ),
  			'section' => 'color_section_basic',
  			),

		// Header.
  		'color_header_background' => array(
  			'label'   => __( 'Background Color', 'restaurantz-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_title' => array(
  			'label'   => __( 'Site Title Color', 'restaurantz-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_title_hover' => array(
  			'label'   => __( 'Site Title Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_tagline' => array(
  			'label'   => __( 'Site Tagline Color', 'restaurantz-pro' ),
  			'section' => 'color_section_header',
  			),

		// Primary Menu.
  		'color_primary_menu_link' => array(
  			'label'   => __( 'Link Color', 'restaurantz-pro' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_menu_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_primary_menu',
  			),
   		'color_primary_menu_link_underline_hover' => array(
  			'label'   => __( 'Link Underline Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_sub_menu_background' => array(
  			'label'   => __( 'Sub Menu Background  Color', 'restaurantz-pro' ),
  			'section' => 'color_section_primary_menu',
  			),

  		// Custom Banner.
  		'color_custom_banner_main_background' => array(
  			'label'   => __( 'Main Background Color', 'restaurantz-pro' ),
  			'section' => 'color_section_custom_banner',
  			),
  		'color_custom_banner_page_title' => array(
  			'label'   => __( 'Title Color', 'restaurantz-pro' ),
  			'section' => 'color_section_custom_banner',
  			),
  		'color_custom_banner_divider' => array(
  			'label'   => __( 'Banner Divider Color', 'restaurantz-pro' ),
  			'section' => 'color_section_custom_banner',
  			),
  		'color_custom_banner_divider_border' => array(
  			'label'   => __( 'Divider Border Color', 'restaurantz-pro' ),
  			'section' => 'color_section_custom_banner',
  			),


		// Content.
  		'color_content_background' => array(
  			'label'   => __( 'Background Color', 'restaurantz-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_text' => array(
  			'label'   => __( 'Text Color', 'restaurantz-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_link' => array(
  			'label'   => __( 'Link Color', 'restaurantz-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_link' => array(
  			'label'   => __( 'Meta Link Color', 'restaurantz-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_link_hover' => array(
  			'label'   => __( 'Meta Link Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_icon' => array(
  			'label'   => __( 'Meta Icon Color', 'restaurantz-pro' ),
  			'section' => 'color_section_content',
  			),

		// Sidebar.
  		'color_sidebar_title' => array(
  			'label'   => __( 'Title Color', 'restaurantz-pro' ),
  			'section' => 'color_section_sidebar',
		),
		'color_sidebar_title_broder' => array(
  			'label'   => __( 'Title Left Broder Color', 'restaurantz-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_text' => array(
  			'label'   => __( 'Text Color', 'restaurantz-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_link' => array(
  			'label'   => __( 'Link Color', 'restaurantz-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_sidebar',
		),


		// Footer area.
  		'color_footer_area_background' => array(
  			'label'   => __( 'Background Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_text' => array(
  			'label'   => __( 'Text Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_link' => array(
  			'label'   => __( 'Link Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_area',
  			),

		// Go To Top.
  		'color_goto_top_icon' => array(
  			'label'   => __( 'Icon Color', 'restaurantz-pro' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_icon_hover' => array(
  			'label'   => __( 'Icon Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_background' => array(
  			'label'   => __( 'Background Color', 'restaurantz-pro' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_background_hover' => array(
  			'label'   => __( 'Background Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_goto_top',
  			),

		// Pagination.
  		'color_pagination_link' => array(
  			'label'   => __( 'Link Color', 'restaurantz-pro' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_background' => array(
  			'label'   => __( 'Link Background Color', 'restaurantz-pro' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_background_hover' => array(
  			'label'   => __( 'Link Background Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_pagination',
  			),

		// Breadcrumb.
  		'color_breadcrumb_background' => array(
  			'label'   => __( 'Background Color', 'restaurantz-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_link' => array(
  			'label'   => __( 'Link Color', 'restaurantz-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_text' => array(
  			'label'   => __( 'Text Color', 'restaurantz-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),

		// Footer Widgets.
  		'color_footer_widgets_background' => array(
  			'label'   => __( 'Background Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_title' => array(
  			'label'   => __( 'Title Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_text' => array(
  			'label'   => __( 'Text Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_link' => array(
  			'label'   => __( 'Link Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_title_border' => array(
  			'label'   => __( 'List Title Broder  Color', 'restaurantz-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),

  		);

    return $choices;

  }

endif;

if( ! function_exists( 'restaurantz_get_color_sections_options' ) ) :

  /**
   * Returns color sections options.
   *
   * @since 1.0.0
   */
	function restaurantz_get_color_sections_options(){

		$choices = array(
			'color_section_basic' => array(
				'label' => __( 'Basic Color Options', 'restaurantz-pro' ),
				),
			'color_section_header' => array(
				'label' => __( 'Header Color Options', 'restaurantz-pro' ),
				),
			'color_section_primary_menu' => array(
				'label' => __( 'Primary Menu Color Options', 'restaurantz-pro' ),
				),
			'color_section_custom_banner' => array(
				'label' => __( 'Custom Banner Color Options', 'restaurantz-pro' ),
				),
			'color_section_content' => array(
				'label' => __( 'Content Color Options', 'restaurantz-pro' ),
				),
			'color_section_sidebar' => array(
				'label' => __( 'Sidebar Color Options', 'restaurantz-pro' ),
				),
			'color_section_breadcrumb' => array(
				'label' => __( 'Breadcrumb Color Options', 'restaurantz-pro' ),
				),
			'color_section_goto_top' => array(
				'label' => __( 'Go To Top Color Options', 'restaurantz-pro' ),
				),
			'color_section_pagination' => array(
				'label' => __( 'Pagination Color Options', 'restaurantz-pro' ),
				),
			'color_section_footer_widgets' => array(
				'label' => __( 'Footer Widgets Color Options', 'restaurantz-pro' ),
				),
			'color_section_footer_area' => array(
				'label' => __( 'Footer Area Color Options', 'restaurantz-pro' ),
				),
			);
		return $choices;
	}

endif;

if ( ! function_exists( 'restaurantz_get_wow_animation_effects_options' ) ) :

	/**
	 * Returns WOW animation effects options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function restaurantz_get_wow_animation_effects_options() {

		$choices = array(
			'bounce'             => _x( 'bounce', 'Animation Effect', 'restaurantz-pro' ),
			'flash'              => _x( 'flash', 'Animation Effect', 'restaurantz-pro' ),
			'pulse'              => _x( 'pulse', 'Animation Effect', 'restaurantz-pro' ),
			'rubberBand'         => _x( 'rubberBand', 'Animation Effect', 'restaurantz-pro' ),
			'shake'              => _x( 'shake', 'Animation Effect', 'restaurantz-pro' ),
			'headShake'          => _x( 'headShake', 'Animation Effect', 'restaurantz-pro' ),
			'swing'              => _x( 'swing', 'Animation Effect', 'restaurantz-pro' ),
			'tada'               => _x( 'tada', 'Animation Effect', 'restaurantz-pro' ),
			'wobble'             => _x( 'wobble', 'Animation Effect', 'restaurantz-pro' ),
			'jello'              => _x( 'jello', 'Animation Effect', 'restaurantz-pro' ),
			'bounceIn'           => _x( 'bounceIn', 'Animation Effect', 'restaurantz-pro' ),
			'bounceInDown'       => _x( 'bounceInDown', 'Animation Effect', 'restaurantz-pro' ),
			'bounceInLeft'       => _x( 'bounceInLeft', 'Animation Effect', 'restaurantz-pro' ),
			'bounceInRight'      => _x( 'bounceInRight', 'Animation Effect', 'restaurantz-pro' ),
			'bounceInUp'         => _x( 'bounceInUp', 'Animation Effect', 'restaurantz-pro' ),
			'bounceOut'          => _x( 'bounceOut', 'Animation Effect', 'restaurantz-pro' ),
			'bounceOutDown'      => _x( 'bounceOutDown', 'Animation Effect', 'restaurantz-pro' ),
			'bounceOutLeft'      => _x( 'bounceOutLeft', 'Animation Effect', 'restaurantz-pro' ),
			'bounceOutRight'     => _x( 'bounceOutRight', 'Animation Effect', 'restaurantz-pro' ),
			'bounceOutUp'        => _x( 'bounceOutUp', 'Animation Effect', 'restaurantz-pro' ),
			'fadeIn'             => _x( 'fadeIn', 'Animation Effect', 'restaurantz-pro' ),
			'fadeInDown'         => _x( 'fadeInDown', 'Animation Effect', 'restaurantz-pro' ),
			'fadeInDownBig'      => _x( 'fadeInDownBig', 'Animation Effect', 'restaurantz-pro' ),
			'fadeInLeft'         => _x( 'fadeInLeft', 'Animation Effect', 'restaurantz-pro' ),
			'fadeInLeftBig'      => _x( 'fadeInLeftBig', 'Animation Effect', 'restaurantz-pro' ),
			'fadeInRight'        => _x( 'fadeInRight', 'Animation Effect', 'restaurantz-pro' ),
			'fadeInRightBig'     => _x( 'fadeInRightBig', 'Animation Effect', 'restaurantz-pro' ),
			'fadeInUp'           => _x( 'fadeInUp', 'Animation Effect', 'restaurantz-pro' ),
			'fadeInUpBig'        => _x( 'fadeInUpBig', 'Animation Effect', 'restaurantz-pro' ),
			'fadeOut'            => _x( 'fadeOut', 'Animation Effect', 'restaurantz-pro' ),
			'fadeOutDown'        => _x( 'fadeOutDown', 'Animation Effect', 'restaurantz-pro' ),
			'fadeOutDownBig'     => _x( 'fadeOutDownBig', 'Animation Effect', 'restaurantz-pro' ),
			'fadeOutLeft'        => _x( 'fadeOutLeft', 'Animation Effect', 'restaurantz-pro' ),
			'fadeOutLeftBig'     => _x( 'fadeOutLeftBig', 'Animation Effect', 'restaurantz-pro' ),
			'fadeOutRight'       => _x( 'fadeOutRight', 'Animation Effect', 'restaurantz-pro' ),
			'fadeOutRightBig'    => _x( 'fadeOutRightBig', 'Animation Effect', 'restaurantz-pro' ),
			'fadeOutUp'          => _x( 'fadeOutUp', 'Animation Effect', 'restaurantz-pro' ),
			'fadeOutUpBig'       => _x( 'fadeOutUpBig', 'Animation Effect', 'restaurantz-pro' ),
			'flipInX'            => _x( 'flipInX', 'Animation Effect', 'restaurantz-pro' ),
			'flipInY'            => _x( 'flipInY', 'Animation Effect', 'restaurantz-pro' ),
			'flipOutX'           => _x( 'flipOutX', 'Animation Effect', 'restaurantz-pro' ),
			'flipOutY'           => _x( 'flipOutY', 'Animation Effect', 'restaurantz-pro' ),
			'lightSpeedIn'       => _x( 'lightSpeedIn', 'Animation Effect', 'restaurantz-pro' ),
			'lightSpeedOut'      => _x( 'lightSpeedOut', 'Animation Effect', 'restaurantz-pro' ),
			'rotateIn'           => _x( 'rotateIn', 'Animation Effect', 'restaurantz-pro' ),
			'rotateInDownLeft'   => _x( 'rotateInDownLeft', 'Animation Effect', 'restaurantz-pro' ),
			'rotateInDownRight'  => _x( 'rotateInDownRight', 'Animation Effect', 'restaurantz-pro' ),
			'rotateInUpLeft'     => _x( 'rotateInUpLeft', 'Animation Effect', 'restaurantz-pro' ),
			'rotateInUpRight'    => _x( 'rotateInUpRight', 'Animation Effect', 'restaurantz-pro' ),
			'rotateOut'          => _x( 'rotateOut', 'Animation Effect', 'restaurantz-pro' ),
			'rotateOutDownLeft'  => _x( 'rotateOutDownLeft', 'Animation Effect', 'restaurantz-pro' ),
			'rotateOutDownRight' => _x( 'rotateOutDownRight', 'Animation Effect', 'restaurantz-pro' ),
			'rotateOutUpLeft'    => _x( 'rotateOutUpLeft', 'Animation Effect', 'restaurantz-pro' ),
			'rotateOutUpRight'   => _x( 'rotateOutUpRight', 'Animation Effect', 'restaurantz-pro' ),
			'hinge'              => _x( 'hinge', 'Animation Effect', 'restaurantz-pro' ),
			'rollIn'             => _x( 'rollIn', 'Animation Effect', 'restaurantz-pro' ),
			'rollOut'            => _x( 'rollOut', 'Animation Effect', 'restaurantz-pro' ),
			'zoomIn'             => _x( 'zoomIn', 'Animation Effect', 'restaurantz-pro' ),
			'zoomInDown'         => _x( 'zoomInDown', 'Animation Effect', 'restaurantz-pro' ),
			'zoomInLeft'         => _x( 'zoomInLeft', 'Animation Effect', 'restaurantz-pro' ),
			'zoomInRight'        => _x( 'zoomInRight', 'Animation Effect', 'restaurantz-pro' ),
			'zoomInUp'           => _x( 'zoomInUp', 'Animation Effect', 'restaurantz-pro' ),
			'zoomOut'            => _x( 'zoomOut', 'Animation Effect', 'restaurantz-pro' ),
			'zoomOutDown'        => _x( 'zoomOutDown', 'Animation Effect', 'restaurantz-pro' ),
			'zoomOutLeft'        => _x( 'zoomOutLeft', 'Animation Effect', 'restaurantz-pro' ),
			'zoomOutRight'       => _x( 'zoomOutRight', 'Animation Effect', 'restaurantz-pro' ),
			'zoomOutUp'          => _x( 'zoomOutUp', 'Animation Effect', 'restaurantz-pro' ),
			'slideInDown'        => _x( 'slideInDown', 'Animation Effect', 'restaurantz-pro' ),
			'slideInLeft'        => _x( 'slideInLeft', 'Animation Effect', 'restaurantz-pro' ),
			'slideInRight'       => _x( 'slideInRight', 'Animation Effect', 'restaurantz-pro' ),
			'slideInUp'          => _x( 'slideInUp', 'Animation Effect', 'restaurantz-pro' ),
			'slideOutDown'       => _x( 'slideOutDown', 'Animation Effect', 'restaurantz-pro' ),
			'slideOutLeft'       => _x( 'slideOutLeft', 'Animation Effect', 'restaurantz-pro' ),
			'slideOutRight'      => _x( 'slideOutRight', 'Animation Effect', 'restaurantz-pro' ),
			'slideOutUp'         => _x( 'slideOutUp', 'Animation Effect', 'restaurantz-pro' ),
		);
		$output = apply_filters( 'restaurantz_filter_wow_animation_effects_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		$output = array( 'no-animation' => __( 'No Animation', 'restaurantz-pro' ) ) + $output;
		return $output;

	}

endif;


if ( ! function_exists( 'restaurantz_get_wow_animation_duration_options' ) ) :

	/**
	 * Returns WOW animation duration options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function restaurantz_get_wow_animation_duration_options() {

		$choices = array(
			'' => __( 'Default', 'restaurantz-pro' ),
			1  => sprintf( __( '%d Second', 'restaurantz-pro' ), 1 ),
			2  => sprintf( __( '%d Seconds', 'restaurantz-pro' ), 2 ),
			3  => sprintf( __( '%d Seconds', 'restaurantz-pro' ), 3 ),
			4  => sprintf( __( '%d Seconds', 'restaurantz-pro' ), 4 ),
			5  => sprintf( __( '%d Seconds', 'restaurantz-pro' ), 5 ),
		);
		$output = apply_filters( 'restaurantz_filter_wow_animation_duration_options', $choices );
		return $output;
	}

endif;

if ( ! function_exists( 'restaurantz_get_wow_animation_delay_options' ) ) :

	/**
	 * Returns WOW animation delay options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function restaurantz_get_wow_animation_delay_options() {

		$choices = array(
			'' => __( 'Default', 'restaurantz-pro' ),
			1  => sprintf( __( '%d Second', 'restaurantz-pro' ), 1 ),
			2  => sprintf( __( '%d Seconds', 'restaurantz-pro' ), 2 ),
			3  => sprintf( __( '%d Seconds', 'restaurantz-pro' ), 3 ),
			4  => sprintf( __( '%d Seconds', 'restaurantz-pro' ), 4 ),
			5  => sprintf( __( '%d Seconds', 'restaurantz-pro' ), 5 ),
		);
		$output = apply_filters( 'restaurantz_filter_wow_animation_delay_options', $choices );
		return $output;
	}

endif;

if ( ! function_exists( 'restaurantz_get_wow_animation_iteration_options' ) ) :

	/**
	 * Returns WOW animation iteration options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function restaurantz_get_wow_animation_iteration_options() {

		$choices = array(
			1 => __( 'Don\'t Repeat', 'restaurantz-pro' ),
			2 => sprintf( __( 'Repeat %dx', 'restaurantz-pro' ), 2 ),
			3 => sprintf( __( 'Repeat %dx', 'restaurantz-pro' ), 3 ),
			4 => sprintf( __( 'Repeat %dx', 'restaurantz-pro' ), 4 ),
			5 => sprintf( __( 'Repeat %dx', 'restaurantz-pro' ), 5 ),
		);
		$output = apply_filters( 'restaurantz_filter_wow_animation_iteration_options', $choices );
		return $output;
	}

endif;
